"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var redux_1 = require("redux");
var store = redux_1.createStore(function () { return ({}); });
var _1 = require(".");
describe('Redux Utils', function () {
    describe('createAction', function () {
        it('no payload', function () {
            var increment = _1.createAction('INCREMENT');
            expect(increment()).toEqual({ type: 'INCREMENT' });
            expect(increment.type).toBe('INCREMENT');
        });
        it('with payload', function () {
            var add = _1.createAction('ADD', function (type) { return function (amount) {
                return ({ type: type, payload: amount });
            }; });
            expect(add(10)).toEqual({ type: 'ADD', payload: 10 });
            expect(add.type).toBe('ADD');
        });
        it('with payload and meta', function () {
            var notify = _1.createAction('NOTIFY', function (type) {
                return function (username, message) { return ({
                    type: type,
                    payload: { message: username + ": " + message },
                    meta: { username: username, message: message },
                }); };
            });
            expect(notify('Piotr', 'Hello!')).toEqual({
                type: 'NOTIFY',
                payload: { message: 'Piotr: Hello!' },
                meta: { username: 'Piotr', message: 'Hello!' },
            });
            expect(notify.type).toBe('NOTIFY');
        });
        it('with payload and no params', function () {
            var showNotification = _1.createAction('SHOW_NOTIFICATION', function (type) {
                return function () { return ({ type: type, payload: 'default message' }); };
            });
            var result = showNotification();
            expect(result).toEqual({
                type: 'SHOW_NOTIFICATION',
                payload: 'default message',
            });
            expect(showNotification.type).toBe('SHOW_NOTIFICATION');
        });
        it('with payload and optional param', function () {
            var showNotification = _1.createAction('SHOW_NOTIFICATION', function (type) {
                return function (message) { return ({ type: type, payload: message }); };
            });
            expect(showNotification()).toEqual({
                type: 'SHOW_NOTIFICATION',
                payload: undefined,
            });
            expect(showNotification.type).toBe('SHOW_NOTIFICATION');
        });
        it('with meta and no params', function () {
            var showError = _1.createAction('SHOW_ERROR', function (type) {
                return function () { return ({ type: type, meta: { type: 'error' } }); };
            });
            expect(showError()).toEqual({
                type: 'SHOW_ERROR',
                meta: { type: 'error' },
            });
            expect(showError.type).toBe('SHOW_ERROR');
        });
        it('with meta and optional param', function () {
            var showError = _1.createAction('SHOW_ERROR', function (type) {
                return function (message) { return ({ type: type, payload: message, meta: { type: 'error' } }); };
            });
            expect(showError()).toEqual({
                type: 'SHOW_ERROR',
                payload: undefined,
                meta: { type: 'error' },
            });
            expect(showError.type).toBe('SHOW_ERROR');
        });
    });
});
//# sourceMappingURL=create-action.spec.js.map