"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const redux_1 = require("redux");
const store = redux_1.createStore(() => ({}));
const _1 = require(".");
describe('Redux Utils', () => {
    describe('createAction', () => {
        it('no payload', () => {
            const increment = _1.createAction('INCREMENT');
            expect(increment()).toEqual({ type: 'INCREMENT' });
            expect(increment.type).toBe('INCREMENT');
        });
        it('with payload', () => {
            const add = _1.createAction('ADD', (type) => (amount) => ({ type, payload: amount }));
            expect(add(10)).toEqual({ type: 'ADD', payload: 10 });
            expect(add.type).toBe('ADD');
        });
        it('with payload and meta', () => {
            const notify = _1.createAction('NOTIFY', (type) => (username, message) => ({
                type,
                payload: { message: `${username}: ${message}` },
                meta: { username, message },
            }));
            expect(notify('Piotr', 'Hello!')).toEqual({
                type: 'NOTIFY',
                payload: { message: 'Piotr: Hello!' },
                meta: { username: 'Piotr', message: 'Hello!' },
            });
            expect(notify.type).toBe('NOTIFY');
        });
        it('with payload and no params', () => {
            const showNotification = _1.createAction('SHOW_NOTIFICATION', (type) => () => ({ type, payload: 'default message' }));
            const result = showNotification();
            expect(result).toEqual({
                type: 'SHOW_NOTIFICATION',
                payload: 'default message',
            });
            expect(showNotification.type).toBe('SHOW_NOTIFICATION');
        });
        it('with payload and optional param', () => {
            const showNotification = _1.createAction('SHOW_NOTIFICATION', (type) => (message) => ({ type, payload: message }));
            expect(showNotification()).toEqual({
                type: 'SHOW_NOTIFICATION',
                payload: undefined,
            });
            expect(showNotification.type).toBe('SHOW_NOTIFICATION');
        });
        it('with meta and no params', () => {
            const showError = _1.createAction('SHOW_ERROR', (type) => () => ({ type, meta: { type: 'error' } }));
            expect(showError()).toEqual({
                type: 'SHOW_ERROR',
                meta: { type: 'error' },
            });
            expect(showError.type).toBe('SHOW_ERROR');
        });
        it('with meta and optional param', () => {
            const showError = _1.createAction('SHOW_ERROR', (type) => (message) => ({ type, payload: message, meta: { type: 'error' } }));
            expect(showError()).toEqual({
                type: 'SHOW_ERROR',
                payload: undefined,
                meta: { type: 'error' },
            });
            expect(showError.type).toBe('SHOW_ERROR');
        });
    });
});
//# sourceMappingURL=create-action.spec.js.map